@@ -1,5 +1,5 @@
 package Text::Hogan;
-$Text::Hogan::VERSION = '0.09';
+$Text::Hogan::VERSION = '1.00';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Text::Hogan - A mustache templating engine statement-for-statement cloned from h
 
 =head1 VERSION
 
-version 0.09
+version 1.00
 
 =head1 DESCRIPTION
 
@@ -24,8 +24,7 @@ It is a L<mustache|https://mustache.github.io/> templating engine which
 supports pre-compilation of your templates into pure Perl code, which then
 renders very quickly.
 
-It aims to pass the full L<mustache spec|https://github.com/mustache/spec>, and
-currently succeeds on all tests except lambda sections.
+It passes the full L<mustache spec|https://github.com/mustache/spec>.
 
 =head1 SYNOPSIS
 
@@ -51,8 +50,8 @@ L<mustache(5)|https://mustache.github.io/mustache.5.html>.
 =head2 hogan.js
 
 L<hogan.js|http://twitter.github.io/hogan.js/> is the original library that
-Text::Hogan is based on. It runs on Node.js and pre-compiles templates to pure
-JavaScript.
+Text::Hogan is based on. It was written and is maintained by Twitter. It runs
+on Node.js and pre-compiles templates to pure JavaScript.
 
 =head2 Text::Caml
 
@@ -65,13 +64,18 @@ L<Template::Mustache|Template::Mustache> is a module written by Pieter van de
 Bruggen and Ricardo Signes. Currently has no POD. Used by
 Dancer::Template::Mustache.
 
+=head2 Mustache::Simple
+
+I don't know anything about L<Mustache::Simple|Mustache::Simple>. It seems to
+be available on search.cpan.org but not on metacpan.org which is a bad sign.
+
 =head1 COPYRIGHT
 
 Copyright (C) 2015 Lokku Ltd.
 
 =head1 AUTHOR
 
-Statement-for-statement copied from hogan.js by Twitter!
+Started out statement-for-statement copied from hogan.js by Twitter!
 
 Alex Balhatchet (alex@lokku.com)
 
