@@ -1,5 +1,5 @@
 package Text::Hogan::Compiler;
-$Text::Hogan::Compiler::VERSION = '0.09';
+$Text::Hogan::Compiler::VERSION = '1.00';
 use Text::Hogan::Template;
 
 use strict;
@@ -512,14 +512,14 @@ sub walk {
 sub parse {
     my ($self, $tokens, $text, $options) = @_;
     $options ||= {};
-    return build_tree($tokens, "", [], $options->{'selection_tags'} || []);
+    return build_tree($tokens, "", [], $options->{'section_tags'} || []);
 }
 
 my %cache;
 
 sub cache_key {
     my ($text, $options) = @_;
-    return join("||", $text, !!$options->{'as_string'}, !!$options->{'disable_lambda'}, ($options->{'delimiters'} || ""), !!$options->{'model_get'});
+    return join("||", $text, !!$options->{'as_string'}, !!$options->{'disable_lambda'}, ($options->{'delimiters'} || ""));
 }
 
 sub compile {
@@ -558,7 +558,7 @@ Text::Hogan::Compiler - parse templates and output Perl code
 
 =head1 VERSION
 
-version 0.09
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -569,7 +569,7 @@ version 0.09
     my $text = "Hello, {{name}}!";
 
     my $tokens   = $compiler->scan($text);
-    my $tree     = $compiler->parse($scanned, $text);
+    my $tree     = $compiler->parse($tokens, $text);
     my $template = $compiler->generate($tree, $text);
 
     say $template->render({ name => "Alex" });
@@ -604,9 +604,9 @@ tree structure ready to be turned into Perl code.
 
     my $tree = $compiler->parse($tokens, $text);
 
-Optionally takes a hashref that can have a key called "selection_tags" which
+Optionally takes a hashref that can have a key called "section_tags" which
 should be an arrayref. I don't know what it does. Probably something internal
-that you don't need to worry about.
+related to recursive calls that you don't need to worry about.
 
 Note that a lot of error checking on your input gets done in this method, and
 it is pretty much the only place exceptions might be thrown. Exceptions which
@@ -664,7 +664,8 @@ strings than byte strings.
 
 I would still recommend you use character strings for your own sanity of
 course! Just be aware that you will gain a lot of performance by pre-compiling
-your templates using the as_string option of compile.
+your templates, either using the as_string option of compile or just using a
+compile-once render-lots pattern in your code.
 
 =head1 COPYRIGHT
 
@@ -672,7 +673,7 @@ Copyright (C) 2015 Lokku Ltd.
 
 =head1 AUTHOR
 
-Statement-for-statement copied from hogan.js by Twitter!
+Started out statement-for-statement copied from hogan.js by Twitter!
 
 Alex Balhatchet (alex@lokku.com)
 
